<ul>
{% for node in nodes %}
    {% if node.pagemeta %}
    <li>
        <a href="{{ node.pagemeta.get_absolute_url }}" hreflang="{{ node.pagemeta.language.code }}" title="{{ node.pagemeta.get_title }}" class="level_{{ node.level }}">{{ node.pagemeta.get_name }}</a>
        {% for other_language in node.pagemeta.get_other_languages %}
            {% if forloop.first %}(other languages:{% endif %}
            {% if not forloop.first %}|{% endif %}
            <a href="{{ other_language.get_absolute_url }}" hreflang="{{ other_language.language.code }}" title="{{ other_language.language.description }}: {{ other_language.get_title }}">{{ other_language.language.code }}</a>
            {% if forloop.last %}){% endif %}
        {% endfor %}
	    {% with "SiteMap/SiteMap_items.html" as filename %}
	    {% with node.subnodes as nodes %}
	       {% if nodes %}<ul>
	       {% include filename %}
	       </ul>{% endif %}
	    {% endwith %}
	    {% endwith %}
    </li>
    {% endif %}
{% endfor %}
</ul>