/* content from:
 * https://github.com/marijnh/CodeMirror/raw/master/js/parsecss.js
 * closure compiled 2011-05-17 */
var CSSParser=Editor.Parser=function(){function k(d,g,h){return function(e){return!d||/^\}/.test(e)?h:g?h+indentUnit*2:h+indentUnit}}var j=function(){function d(b,c){var a=b.next();return a=="@"?(b.nextWhileMatches(/\w/),"css-at"):a=="/"&&b.equals("*")?(c(g),null):a=="<"&&b.equals("!")?(c(h),null):a=="="?"css-compare":b.equals("=")&&(a=="~"||a=="|")?(b.next(),"css-compare"):a=='"'||a=="'"?(c(e(a)),null):a=="#"?(b.nextWhileMatches(/\w/),"css-hash"):a=="!"?(b.nextWhileMatches(/[ \t]/),b.nextWhileMatches(/\w/),
"css-important"):/\d/.test(a)?(b.nextWhileMatches(/[\w.%]/),"css-unit"):/[,.+>*\/]/.test(a)?"css-select-op":/[;{}:\[\]]/.test(a)?"css-punctuation":(b.nextWhileMatches(/[\w\\\-_]/),"css-identifier")}function g(b,c){for(var a=!1;!b.endOfLine();){var f=b.next();if(a&&f=="/"){c(d);break}a=f=="*"}return"css-comment"}function h(b,c){for(var a=0;!b.endOfLine();){var f=b.next();if(a>=2&&f==">"){c(d);break}a=f=="-"?a+1:0}return"css-comment"}function e(b){return function(c,a){for(var f=!1;!c.endOfLine();){var e=
c.next();if(e==b&&!f)break;f=!f&&e=="\\"}f||a(d);return"css-string"}}return function(b,c){return tokenizer(b,c||d)}}();return{make:function(d,g){var g=g||0,h=j(d),e=!1,b=!1,c=!1,a={next:function(){var a=h.next(),d=a.style,i=a.content;if(d=="css-hash")d=a.style=b?"css-colorcode":"css-identifier";if(d=="css-identifier")if(b)a.style="css-value";else if(!e&&!c)a.style="css-selector";if(i=="\n")a.indentation=k(e,b,g);i=="{"&&c=="@media"?c=!1:i=="{"?e=!0:i=="}"?e=b=c=!1:i==";"?b=c=!1:e&&d!="css-comment"&&
d!="whitespace"?b=!0:!e&&d=="css-at"&&(c=i);return a},copy:function(){var c=e,d=b,i=h.state;return function(g){h=j(g,i);e=c;b=d;return a}}};return a},electricChars:"}"}}();