{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
{% extrahead %}
<!-- sf_main_menu.html extrahead START -->
{% compress css %}
<link rel="stylesheet" type="text/css" media="screen" href="{{ STATIC_URL }}PyLucid/superfish/superfish.css" onerror="JavaScript:alert('{{ STATIC_URL }}PyLucid/superfish/superfish.css');" />
{% endcompress %}
{% compress js %}
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/superfish/superfish.js" onerror="JavaScript:alert('{{ STATIC_URL }}PyLucid/superfish/superfish.js');" ></script>
{% endcompress %}
<!-- sf_main_menu.html extrahead END -->
{% endextrahead %}
{% spaceless %}
<ul class="sf-menu sf-main_menu">
    {% include "sf_main_menu/sf_main_menu_items.html" %}
</ul>
{% endspaceless %}
{% endblock %}