<h2><a href="{{ entry.get_absolute_url }}" class="blog_headline" hreflang="{{ entry.language.code }}">{{ entry.url_date|date:_("DATE_FORMAT") }} - {{ entry.headline }}</a></h2>
<small class="headline_info" title="{{ entry.url_date|date:_("DATETIME_FORMAT") }}">{% blocktrans with entry.url_date|timesince as time %}Before {{ time }} published by{% endblocktrans %} {{ entry.createby }}.</small>

{% if not entry.is_public %}
    <p class="admin_info_line">not public</p>
{% endif %}

{% include "blog/includes/admin_links.html" %}

<div class="content" lang="{{ entry.language.code }}">{{ entry.get_html }}</div>

{% if entry.lastupdatetime|date:"r" != entry.createtime|date:"r" %}{# compare in RFC2822 format: without microseconds #}
<small><p class="date_info">
    (Last update: {{ entry.lastupdatetime|date:_("DATETIME_FORMAT") }} by {{ entry.lastupdateby }}.)
</p></small>
{% endif %}

{% include "blog/includes/taglist.html" %}