{% extends template_name %}

{% block content %}
{# {% include "blog/includes/tagcloud.html" %} #}
{% include "lexicon/includes/admin_links.html" %}
<dl>
    <dt>{% trans "Term" %}:</dt>
    <dd>{{ entry.term }}</dd>
    
    <dt>{% trans "Short definition" %}:</dt>
    <dd>{{ entry.short_definition }}</dd>
    
    <dt>{% trans "Content" %}:</dt>
    <dd>{{ entry.get_html }}</dd>
</dl>
{% endblock content %}