{% csrf_token %}
{% include "admin/pylucid/includes/form_fieldset_errorlist.html" %}
<fieldset>
    {% include "admin/pylucid/includes/buttons_save_abort.html" %}
    {% include "admin/pylucid/includes/pylucid_formset.html" %}
    {% include "admin/pylucid/includes/buttons_save_abort.html" %}
</fieldset>