{# comment form, send via AJAX used form preview, too. Based on django/contrib/comments/templates/comments/preview.html #}
<form action="JavaScript:void(0)" method="post" id="comment_form">
    {% if next %}<input type="hidden" name="next" value="{{ next }}" />{% endif %}
    
    {% if form.errors %}
    <h1>{% blocktrans count form.errors|length as counter %}Please correct the error below{% plural %}Please correct the errors below{% endblocktrans %}</h1>
    {% endif %}
      
    {% for field in form %}
      {% if field.name == "honeypot" %}
        <span style="display:none;">{{ field }}</span>
      {% else %}
        {% include "admin/pylucid/includes/form_field.html" %}
      {% endif %}
    {% endfor %}
    <p class="submit">
    <input type="submit" name="submit" class="submit-post" value="{% trans "Post" %}" />
    <input type="submit" name="preview" class="submit-preview" value="{% trans "Preview" %}" />
    </p>
</form>
