{% extends "admin/base_site.html" %}

{% block content %}
<div class="pylucid_form">   
    <div class="field">
        <ul>
            {% for language in other_languages %}
            <li><a href="?language={{ language.code }}">{{ language.description }}</li>
            {% endfor %}
        </ul>
    </div>
    
    <div class="helper_buttons">
        <a href="{{ abort_url }}"><button type="button">{% trans 'abort' %}</button></a>
    </div>
</div>
{% endblock %}