{# The special placeholder '<!-- word -->' would be replace with match word in the text. #}
<a href="?lexicon={{ term }}" title="lexicon entry '{{ term }}' - {{ short_definition }}" class="PyLucidPlugins lexicon openinwindow"><!-- word --></a>