{% for design in designs %}
  <a href="{% url admin:pylucid_design_change design.pk %}" class="add_openinwindow" title="{% trans "edit design" %}">{{ design.name }}</a><br />
{% empty %}
  -
{% endfor %}
