{% extends "admin/base_site.html" %}

{% block content %}
<p>
    A copy of all Design componets (like Template, Headfiles, ColorScheme) would be created with the new name you given here.<br/>
</p>
<form action="{{ form_url }}" method="post" id="clone_design_form" class="pylucid_form">
	{% csrf_token %}
    {% include "admin/pylucid/includes/form_fieldset_errorlist.html" %}
    {% include "admin/pylucid/includes/markup_preview_fieldset.html" %}
    <fieldset>
        {% include "admin/pylucid/includes/pylucid_formset.html" %}
        <div class="helper_buttons">
            <input type="submit" name="save" value="{% trans 'clone design' %}" />      
        </div>
    </fieldset>
</form>
<h2>links</h2>
<ul>
    <li>Use the <strong><a href="{% url Design-switch %}">design switch function</a></strong>, to see the cloned design in action.</li>
    <li>For a better overview, go to <strong><a href="{% url admin:pylucid_design_changelist %}">design change list</a></strong>.</li>
    <li>more info: <a href="/permalink/69/customise-the-look-of-your-pylucid-installation">customise the look of your PyLucid installation</a></li>
</ul>
{% endblock %}
