{% extends "page_admin/markup_help_base.html" %}

{% block content %}{{ block.super }}
<h2>links</h2>
<ul>
	<li><a class="add_openinwindow" href="http://selfhtml.org">selfhtml.org</a></li>
	<li><a class="add_openinwindow" href="http://en.wikipedia.org/wiki/Hypertext_Markup_Language">en.wikipedia.org/wiki/Hypertext_Markup_Language</a></li>
</ul>
{% include "page_admin/includes/markup_help_common.html" %}
{% endblock content %}