{% extends template_name %}
{% load comments %}

{% block content %}
<div class="{{ CSS_PLUGIN_CLASS_NAME }} lexicon">
{# {% include "blog/includes/tagcloud.html" %} #}

{% if not entries %}no lexicon entry exists{% endif %}
<dl>
{% for entry in entries %}
    <dt>
        <a href="{{ entry.get_absolute_url }}">{{ entry.term }}</a>
        {% include "lexicon/includes/admin_links.html" %}
    </dt>
    <dd>{{ entry.short_definition }}</dd>
{% endfor %}
</dl>
</div>
{% endblock content %}