{% if not form %}ERROR: Form unknown!{% endif %}
<ul class="errorlist">
{% for field_name, errors in form.errors.items %}
    <li title="'{{ field_name }}' errors">
    <a href="#{{ field_name }}_errors">{{ field_name }}:
    {% for error in errors %}
        {{ error }}
        {% if not forloop.last %},{% endif %}
    {% endfor %}
    </a>
    </li>
{% endfor %}
</ul>