{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
{% extrahead %}
<style>
#poll_lucidTag.PyLucidPlugins .bar {
	height: 3px;
	background-color: #000080;
}
#poll_lucidTag.PyLucidPlugins li {
	height: 2.5em;
}
</style>
{% endextrahead %}
<fieldset><legend>Poll</legend>
<h3>{{ poll.question }}</h3>
{% if poll_message %}<p><strong>{{ poll_message }}</strong></p>{% endif %}
<ul>
{% for choice in poll.choice_set.all %}
    <li>
    	<div class="bar" style="width:{{ choice.percent }}%;">&nbsp;</div>
    	{{ choice.votes }} vote{{ choice.votes|pluralize }} ({{ choice.percent|floatformat:1 }}%) for: {{ choice.choice }}
    </li>
{% endfor %}
</ul>
</fieldset>
{% endblock plugin_content %}