{# for sourounding plugin output with css anchors #}

<span class="{{ CSS_PLUGIN_CLASS_NAME }} {{ css_plugin_class }}" id="{{ css_plugin_id }}">
{% block plugin_content %}Error in template from plugin '{{ css_plugin_class }}': It must extends the block 'plugin_content'!{% endblock %}
</span>