{% load comments %}

<ul>
{% get_comment_list for object2comment as comment_list %}
{% for comment in comment_list %}
<li>
<fieldset class="comment {% if comment.user_name %}{{ comment.user_name }}{% else %}anonymous{% endif %}_comment">
    <legend class="headline">
    {{ forloop.counter }}.
    {% if comment.user_url %}
        <a href="{{ comment.user_url }}" title="{{ comment.user_url }}">{{ comment.user_name }}</a>:
    {% else %}
        {{ comment.user_name }}:
    {% endif %}
    <br />
        <small class="headline_info">
          {% blocktrans with comment.submit_date|timesince as time %}Before {{ time }}{% endblocktrans %}
          IP: {{ comment.ip_address }}
          {% if comment.lastupdateby %}<br />(Last update {{ comment.lastupdatetime|date:_("DATETIME_FORMAT") }} by {{ comment.lastupdateby }}){% endif %}
        </small>
    </legend>
    
    {% if perms.pylucid_comments.change_pylucidcomment or perms.pylucid_comments.delete_pylucidcomment %}
    <div class="admin_links">
        {% if perms.pylucid_comments.change_pylucidcomment %}
            <a href="{% url admin:pylucid_comments_pylucidcomment_change comment.id %}" title="{% trans 'edit this comment entry' %}">{% trans 'edit' %}</a>
        {% endif %}
        {% if perms.pylucid_comments.delete_pylucidcomment %}
            <a href="{% url admin:pylucid_comments_pylucidcomment_delete comment.id %}" title="{% trans 'delete this comment entry' %}">{% trans 'delete' %}</a>
        {% endif %}
    </div>
    {% endif %}
    
    {% if not comment.is_public %}
        <p class="admin_info_line">not public</p>  
    {% else %}
        {{ comment.comment }}
    {% endif %} 
</fieldset>
</li>
{% empty %}
    {% blocktrans with object2comment.get_name as name %}there exist no comment for '{{ name }}'{% endblocktrans %}
{% endfor %}
</ul>