{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
{% if update_list %}
<table id="page_updates">
  <tr>
    <th>{% trans "update time" %}</th>
    <th>{% trans "title" %}</th>
    <th>{% trans "user name" %}</th>
    {% if perms.update_journal.change_updatejournal or perms.update_journal.delete_updatejournal %}
        <th>{% trans "actions" %}</th>
    {% endif %}
  </tr>
  {% for item in update_list %}
  <tr class="{% cycle 'row1' 'row2' %}">
    <td class="update_time">{{ item.lastupdatetime|date:_("DATETIME_FORMAT") }}</td>
    <td class="update_title"><a href="{{ item.object_url }}">{{ item.title|escape }}</a><br /><small>({{ item.content_type }})</small></td>
    <td class="update_user">{{ item.user_name }}</td>
    {% if perms.update_journal.change_updatejournal or perms.update_journal.delete_updatejournal %}
    <td class="update_actions">
        {% if perms.update_journal.change_updatejournal %}
            <a href="{% url admin:update_journal_updatejournal_change item.id %}" title="edit '{{ item.title|escape }}'">{% trans "edit" %}</a>
        {% endif %}
        {% if perms.update_journal.delete_updatejournal %}
            <a href="{% url admin:update_journal_updatejournal_delete item.id %}" title="Delete '{{ item.title|escape }}' from the list">{% trans "delete" %}</a>
        {% endif %}
    </td>
    {% endif %}
  </tr>
  {% endfor %}
</table>
{% if select_feed_url %}
<a href="{{ select_feed_url }}" class="select_feeds" title="{% trans "select update journal feed format" %}">
   {% trans "get update journal as RSS/Atom feed." %}
</a>
{% endif %}
{% else %}
    <p>{% trans "No updates recorded in update journal." %}</p>
{% endif %}
{% endblock %}