[StreetMap Error{% if perms.StreetMap.add_mapentry %}: You should create a map entry, named '<strong>{{ name }}</strong>': <span class="admin_links"><a href="{% url admin:StreetMap_mapentry_add %}" title="{% trans 'create a new street map entry in django admin site' %}" class="add_openinwindow">{% trans 'create a new map entry' %}</a></span>{% endif %}]