{% if first_page %}
    <a href="{{ first_page.get_absolute_uri }}" class="openinwindow" title="{% trans "Open the first page witch used this design" %}">{{ count }}</a>
{% else %}
    {{ count }}
{% endif %}
