form.wysiwyg {
	background:#fff;
	padding:1em;
	border:1px solid #eee;
        margin:2px;
        width:25em;
}
form.wysiwyg fieldset div {
	margin:0.3em 0;
	clear:both;
	margin-bottom:5px;
}
form.wysiwyg label {
	display: block;
	width:10em;
	text-align:right;
	margin-right:1em;
}
form.wysiwyg legend {
	color:#0b77b7;
	font-size:1.2em;
}
form.wysiwyg legend span {
	width:10em;
	text-align:right;
}
form.wysiwyg input {
	padding:0.15em;
	width:10em;
	border:1px solid #ddd;
	background:#fafafa;
	font:bold 0.95em arial, sans-serif;
	margin-bottom:5px;
	-moz-border-radius:0.4em;
	-khtml-border-radius:0.4em;
}
form.wysiwyg input:hover, form.wysiwyg input:focus {
	border-color:#c5c5c5;
	background:#f6f6f6;
} 
form.wysiwyg .button{
	margin-top:8px;
}
form.wysiwyg fieldset {
	border:1px solid #ddd;
	padding:0 0.5em 0.5em;
}

form.wysiwyg input.default {
	color:#bbb;
}
