<a href="http://www.openstreetmap.org/?lon={{ map.lon }}&lat={{ map.lat }}&zoom={{ map.zoom }}" title="{% trans "See this map on OpenStreetMap webpage" %}" class="add_openinwindow googlemaps">www.openstreetmap.org</a>