{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
<fieldset><legend>Poll</legend>
<h3>{{ poll.question }}</h3>
<form action="?poll=vote&id={{ poll.id }}" method="post">{% csrf_token %}
{% for choice in poll.choice_set.all %}
    <input type="radio" name="choice" id="choice{{ forloop.counter }}" value="{{ choice.id }}" />
    <label for="choice{{ forloop.counter }}">{{ choice.choice }}</label><br />
{% endfor %}
<input type="submit" value="Vote" />
</form>
</fieldset>
{% endblock plugin_content %}