<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="{{ entry.language.code }}" lang="{{ entry.language.code }}">
<head>
<title>{{ entry.term }}</title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<meta name="robots" content="{{ page_robots }}" />
<meta name="keywords" content="{{ entry.term }}{% if entry.alias %} {{ entry.alias }}{% endif %}{% if entry.tags %} {{ entry.tags }}{% endif %}" />
<meta name="description" content="{{ entry.short_definition }}" />
<meta name="DC.Date" content="{{ entry.lastupdatetime|date:_("DATETIME_FORMAT") }}" />
<meta name="DC.Date.created" content="{{ entry.createtime|date:_("DATETIME_FORMAT") }}" />
<link rel="canonical" href="{{ page_permalink }}" />
<script type="text/javascript" src="{{ STATIC_URL }}admin/js/jquery.min.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');" ></script>
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/pylucid_js_tools.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');"></script>
<style type="text/css">
html {
    background-color: #eee; 
}
body{
  font-size:0.9em;
  background-color: #fff;
  margin: 15px 10% 15px 10%;
  padding: 1em;
}
#footer, #footer * {
  font-size:0.8em;
  color: #ddd;
  text-align:center;
}
</style>
{% block extrahead %}{% endblock %}
<!-- ContextMiddleware extrahead -->
</head>
<body>
<div id="page_content">
    {% if summary_url %}<a href="{{ summary_url }}">&lt;&lt; {% trans "goto lexicon summary page" %}</a>{% endif %}
    <h1>{{ entry.term }}</h1>
    {# {% include "blog/includes/tagcloud.html" %} #}
    {% include "lexicon/includes/admin_links.html" %}
    <dl>   
        <dt>{% trans "Short definition" %}:</dt>
        <dd>{{ entry.short_definition }}</dd>
        
        <dt>{% trans "Content" %}:</dt>
        <dd>{{ entry.get_html }}</dd>
    </dl>
    {% lucidTag pylucid_comments %}
</div>
<div id="footer">
    <p>
      powered by {{ powered_by }} | {% lucidTag auth %} | <!-- script_duration --> | last modified: {{ entry.lastupdatetime|date:_("DATETIME_FORMAT") }}
    </p>
</div>
</body>
</html>