{% extends "pylucid/css_anchor_div.html" %}


{% block plugin_content %}

{% extrahead %}
{% include "admin_menu/includes/superfish_extrahead.html" %}
{% endextrahead %}

{% include "admin_menu/includes/pylucid_admin_menu.html" %}
{% endblock %}