<div class="helper_buttons">
    <input type="submit" name="save" value="{% trans 'save' %}" />
    <input onclick="self.location.href='{{ abort_url }}'" name="abort" value="{% trans 'abort' %}" type="reset" />
</div>