{% extends "admin/base_site.html" %}
{% load i18n %}

{% block branding %}<a name="top" /><h1 class="admin_headline">PyLucid Update
{% if not sites|length_is:"1" %}
    <small>(site: <strong title="Update on site '{{ site.domain }}'">{{ site.name }}</strong>)</small>
{% endif %}
</h1>
<!-- page_messages -->
{% endblock %}

{% block breadcrumbs %}{% if not is_popup %}
<div class="breadcrumbs">
     <a href="{% url admin:index %}">Home</a> ›
     <strong><a href="{% url PyLucidUpdate-menu %}" title="update menu">Update</a></strong> ›
     {{ title }}
</div>{% endif %}
{% endblock %}