{% for node in nodes %}
    {% if node.pagemeta %}
	    <li>
            {% if node.visible %}
    	        {% if node.current %}<strong>{% endif %}
    	        <a href="{{ node.pagemeta.get_absolute_url }}" hreflang="{{ node.pagemeta.language.code }}" title="{{ node.pagemeta.get_title }}" class="{{ node.css_class }}">{{ node.pagemeta.get_name }}</a>
    	        {% if node.current %}</strong>{% endif %}
            {% endif %}

            {% if node.subnodes %}
                {% with "main_menu/main_menu_items.html" as filename %}
    	        {% with node.subnodes as nodes %}
	            <ul>{% include filename %}</ul>
    	        {% endwith %}
    	        {% endwith %}
            {% endif %}	        
	    </li>
    {% endif %}
{% endfor %}