{% extends template_name %}

{% block content %}
<div class="{{ CSS_PLUGIN_CLASS_NAME }} update_journal_feed">
<h2>{% trans "Please select syndication feed format:" %}</h2>
<ul>
{% for filename in filenames %}
    <li>
        <a href="{% url UpdateJournal-feed filename %}">{% url UpdateJournal-feed filename %}</a>
        <small>(
        {% if filename == "feed.rss" %}
            <a href="{% trans "http://en.wikipedia.org/wiki/RSS" %}">Really Simple Syndication</a> v2.01rev2
        {% endif %}
        {% if filename == "feed.atom" %}   
            <a href="{% trans "http://en.wikipedia.org/wiki/Atom_(standard)" %}">Atom Syndication Format</a> v1.0
        {% endif %}
        )
        </small>
    </li>
{% endfor %}
</lu>
</div>
{% endblock content %}