{% extends "pylucid_admin/base_site.html" %}
{% load i18n %}

{% block content %}
<!-- view_content block -->
<fieldset><legend>base check</legend>
<pre>{{ results }}</pre>
</fieldset>
<!-- view_content block end -->
{% endblock %}