<h{{ no }} id="{{ anchor }}" class="headline_anchor">
<a href="#top" title="{% trans 'go top' %}" class="top_link"><span class="uarr">&uarr;&nbsp;</span>{{ link_text }}</a>
<a title="{% trans 'Permalink to this section' %}" href="{{ anchor_link }}" class="section_anchor">&nbsp;#</a>
</h{{ no }}>