{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
<fieldset>
<legend><a href="{{ url }}">{{ feed.feed.title }}</a></legend>
{% if user.is_staff %}
<p><small>
    Use feed {% if from_cache %}from cache{% else %}not from cache{% endif %}.
    Feed server response time was: {{ duration|floatformat:3 }}sec.<br />
    Used preferences: {{ preferences }}<br />
    max entries: {{ max_entries }}
</small></p>
{% endif %}
<ul>
{% for entry in feed.entries %}
    <li>
    <h1><a href="{{ entry.link }}">{{ entry.title|striptags }}</a></h1>
    <p>
      {{ entry.updated }}<br />
      {{ entry.summary|striptags }}
    </p>
    </li>
{% endfor %}
</ul>
</fieldset>
{% endblock %}