{% extends "admin/base_site.html" %}

{% block content %}
<p>
	To delete everything stored in the Django's cache framework:
	<ul><li><a href="?doit">Delete cache entries</a></li></ul>
</p>
{% endblock %}
