/* Styles for map display */
#map {
  height: 100%;
  width: 100%;
  padding: 0;
  margin: 0;
  border: 1px solid #cdcdcd;
}

#map_container {
    padding: 0px;
    margin: auto;
    width: 534px;
    height: 340px;
    text-align: right;
    z-index: 1;
}

#osm {
  font-size: 0.7em;
  font-style: normal;
}

#tbubble {
  /* border: 1px solid #cdcdcd; */
  width: 135px;
  margin: auto;
  color:#9A9A9A;
  font-size:12px;
  font-weight:normal;
  text-align: center;
}