{% load tagging_tags %}

<fieldset class="taglist"><legend>tags</legend>
{% tags_for_object entry as tags %}
{% for tag in tags %}
    {% if not forloop.first %}|{% endif %}
    {% if tag.name in used_tags %}
        <strong>{{ tag.name }}</strong>
    {% else %}
        <a href="{% url Blog-tag_view tags=tag.name %}" rel="nofollow">{{ tag.name }}</a> 
    {% endif %}
    {% if add_tag_filter_link %}
        {% include "blog/includes/add_tag_filter.html" %}
    {% endif %}
{% endfor %}
</fieldset>