{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
<ul>
  {% for language in existing_languages %}
  <li>
    {% ifequal language current_language %}
        <strong title="Current used language is '{{ language.description }}'.">{{ language.description }}</strong>
    {% else %}
        <a href="?language={{ language.code }}" hreflang="{{ language.code }}" title="switch to {{ language.description }}">
            {{ language.description }}
        </a>
    {% endifequal %}
  </li>
  {% endfor %}
  {% if add_reset_link %}
  <li class="reset_link"><a href="?language={{ reset_key }}">reset favored language</a></li>
  {% endif %}
</ul>
{% endblock plugin_content %}