{% extends "pylucid/css_anchor_span.html" %}

{% block plugin_content %}
<a href="{{ honypot_url }}" id="login_link" rel="nofollow" onclick="return get_pylucid_ajax_view('{{ url }}');">{% trans 'Log in' %}</a>
{% endblock %}