{% for node in nodes %}
{% if node.visible %}
<li>
    <a href="{{ node.data.absolute_url }}" title="{{ node.data.title }}">{{ node.data.name }}</a>
    {% with "admin_menu/admin_menu_items.html" as filename %}
    {% with node.subnodes as nodes %}
       {% if nodes %}<ul>
       {% include filename %}
       </ul>{% endif %}
    {% endwith %}
    {% endwith %}
</li>
{% endif %}
{% endfor %}
