{% extends "admin/base_site.html" %}
{% load i18n %}

{% block branding %}<a name="top" /><h1 class="admin_headline">PyLucid admin</h1>
<!-- page_messages -->
{% endblock %}

{% block breadcrumbs %}{% if not is_popup %}
<div class="breadcrumbs">
     <a href="{% url admin:index %}">Home</a> ›
     <a href="{% url PyLucidAdmin-menu %}">PyLucid admin</a> ›
     {{ title }}
</div>{% endif %}
{% endblock %}