<div class="helper_buttons">
    <input type="submit" name="save" value="{% trans 'save' %}" />
    <input onclick="self.location.href='{{ abort_url }}'" name="abort" value="{% trans 'abort' %}" type="reset" />
    <input type="submit" name="autotranslate" value="{% trans 'auto translate' %}" title="{% trans 'Translate fields with google translation service.' %}" />
</div>