{% extends "admin/base_site.html" %}

{% block extrastyle %}{{ block.super }}
<!-- update_env status.html extrastyle block start -->
<style type="text/css">
#update_env li {
    background-color: #fafafa;
    list-style-type: none;
    margin: 4em 0em;
    padding: 1em;
    border: 1px solid #ddd;
}
#update_env li pre {
    color: #000;
}
</style>
<!-- update_env status.html extrastyle block end -->
{% endblock extrastyle %}


{% block content %}

{% lucidTag TOC %}

{% if env_path %}
<p>Base env path: <strong>{{ env_path }}</strong>.</p>
<ul id="update_env">
{% for package_name, package in vcs_info.package_info.items %}
    <li>
    <h2>{{ package_name }}</h2>
	<pre>{{ package.output }}</pre>
	
	<div class="helper_buttons">  
    <a href="{% url Update-update package_name %}">
        <button type="button" class="button">update {{ package_name }}</button>
    </a>
    </div>
    </li>		
{% endfor %}
</ul>
{% endif %}
{% endblock %}
