{% extends "pylucid/css_anchor_div.html" %}

{% block plugin_content %}
<p>
{% if preferences.print_index %}
  <a href="{{ preferences.index_url }}">{{ preferences.index|escape }}</a>{{ preferences.separator }}
{% endif %}
  {% for link in linklist %}
    <a href="{{ link.url }}"{% if link.title %} title="{{ link.title|escape }}"{% endif %}>{{ link.name|escape }}</a>
    {% if not forloop.last %}{{ preferences.separator }}{% endif %}
  {% endfor %}
</p>
{% endblock %}