{% extends "admin/change_list.html" %}
{% load i18n %}


{% block content %}
<!-- admin/pylucid/change_list_with_design_link - content - START -->
<ul>
    <li>{% include "admin/pylucid/includes/design_link.html" %}</li>
</ul>
<!-- admin/pylucid/change_list_with_design_link - content - END -->
{{ block.super }}{% endblock %}
