{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}PyLucid - {{ title }}{% endblock %}

{% block extrahead %}{{ block.super }}
{% if debug %}<!-- ./apps/pylucid/templates/admin/base_site.html extrahead block START -->{% endif %}
{% compress js %}
<script type="text/javascript">
    var PyLucid_media_url="{{ STATIC_URL }}PyLucid/";
    var markup_help_url="{% url PageAdmin-markup_help %}";
</script>
<script type="text/javascript" src="{{ STATIC_URL }}admin/js/jquery.min.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');" ></script>
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/pylucid_js_tools.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');"></script>
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/codemirror/codemirror_min.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');"></script>
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/jwysiwyg/jquery.wysiwyg.js" onerror="JavaScript:alert('Error loading file ['+this.src+'] !');"></script>
{% if debug %}
   <script type="text/javascript">var debug=true;log("debug is on");</script>
{% else %}
   <script type="text/javascript">var debug=false;</script>
{% endif %}
{% endcompress %}
{% include "admin_menu/includes/superfish_extrahead.html" %}
{% if debug %}<!-- ./apps/pylucid/templates/admin/base_site.html extrahead block END -->{% endif %}
{% endblock extrahead %}


{% block extrastyle %}{% compress css %}{{ block.super }}
{% if debug %}<!-- ./apps/pylucid/templates/admin/base_site.html extrastyle block START -->{% endif %}
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}PyLucid/jwysiwyg/jquery.wysiwyg.css" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" />
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}PyLucid/pylucid_admin.css" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" />
<style type="text/css">
/* ----------------------------------------------------------------------------
   Highlight important models and grayed out non important ones in django admin
------------------------------------------------------------------------------- */
.module th a[href="{% url admin:index %}auth/permission/"],
.module th a[href="{% url admin:index %}contenttypes/contenttype/"],
.module th a[href="{% url admin:index %}pylucid/color/"],
.module th a[href="{% url admin:index %}pylucid/userprofile/"],
.module th a[href="{% url admin:index %}PyLucid_Update/blogcomment08/"],
.module th a[href="{% url admin:index %}PyLucid_Update/blogentry/"],
.module th a[href="{% url admin:index %}PyLucid_Update/blogtag/"],
.module th a[href="{% url admin:index %}PyLucid_Update/js/logindata08/"],
.module th a[href="{% url admin:index %}PyLucid_Update/page08/"],
.module th a[href="{% url admin:index %}PyLucid_Update/style08/"],
.module th a[href="{% url admin:index %}PyLucid_Update/template08/"],
.module th a[href="{% url admin:index %}reversion/revision/"],
.module th a[href="{% url admin:index %}reversion/version/"],
.module th a[href="{% url admin:index %}tagging/taggeditem/"],
.module th a[href="{% url admin:index %}tagging/tag/"] {
    color: #aaa;
}

.module th a[href="{% url admin:index %}dbpreferences/preference/"],
.module th a[href="{% url admin:index %}dbtemplates/template/"],
.module th a[href="{% url admin:index %}pylucid/design/"],
.module th a[href="{% url admin:index %}pylucid/logentry/"],
.module th a[href="{% url admin:index %}redirect/redirectmodel/"],
.module th a[href="{% url admin:index %}redirects/redirect/"],
.module th a[href="{% url admin:index %}StreetMap/mapentry/"],
.module th a[href="{% url admin:index %}django/processinfo/sitestatistics/"] {
    background-color: #e8eff6;
    border-left: 5px solid #acc5e1;
    display: block;
}
.module th {
    padding: 0px;
    vertical-align:middle;
}
.module th a {
    padding: 5px;
    vertical-align:middle;
}
</style>
{% lucidTag extrahead filepath="pygments.css" %}
{% if debug %}<!-- ./apps/pylucid/templates/admin/base_site.html extrastyle block END -->{% endif %}
{% endcompress %}
{% endblock extrastyle %}


{% block branding %}<h1 class="admin_headline" id="top">PyLucid</h1>
<!-- page_messages -->
{% endblock %}


{% block pretitle %}
<!-- app pretitle block start -->
{% if request.user.is_authenticated %}
{% include "admin_menu/includes/pylucid_admin_menu.html" %}
{% endif %}
<!-- app pretitle block end -->
{% endblock %}


{% block footer %}
<!-- app footer block start -->
<div class="footer">
    {% trans 'page stats:' %} <!-- script_duration --> | powered by: {{ powered_by }}
</div>
<!-- app footer block end -->
{% endblock %}