
div.wysiwyg { border: 1px solid #ccc; padding: 5px; background-color: #fff; }
div.wysiwyg * { margin: 0; padding: 0; }

div.wysiwyg ul.panel { border-bottom: 1px solid #ccc; float: left; width: 100%; padding: 0; }
div.wysiwyg ul.panel li { list-style: none; float: left; margin: 1px 2px 3px 0;  background: #fff; -moz-user-select: none; -webkit-user-select: none; user-select: none;}
div.wysiwyg ul.panel li.separator { width: 1px; height: 16px; margin: 0 4px; border-left: 1px solid #ccc; }
div.wysiwyg ul.panel li { text-indent: -5000px; opacity: 0.85; filter:alpha(opacity=85); display: block; width: 16px; height: 16px; background: url('jquery.wysiwyg.gif') no-repeat -64px -80px; border: 0; cursor: pointer; margin: 1px; }
div.wysiwyg ul.panel li.wysiwyg-button-hover, div.wysiwyg ul.panel li.active { opacity: 1.00; filter:alpha(opacity=100); }
div.wysiwyg ul.panel li.active { background-color: #f9f9f9; border: 1px solid #ccc; border-left-color: #aaa; border-top-color: #aaa; margin: 0; }

div.wysiwyg ul.panel li.bold { background-position: 0 -16px; }
div.wysiwyg ul.panel li.italic { background-position: -16px -16px; }
div.wysiwyg ul.panel li.strikeThrough { background-position: -32px -16px; }
div.wysiwyg ul.panel li.underline { background-position: -48px -16px; }

div.wysiwyg ul.panel li.justifyLeft { background-position: 0 0; }
div.wysiwyg ul.panel li.justifyCenter { background-position: -16px 0; }
div.wysiwyg ul.panel li.justifyRight { background-position: -32px 0; }
div.wysiwyg ul.panel li.justifyFull { background-position: -48px 0; }

div.wysiwyg ul.panel li.indent { background-position: -64px 0; }
div.wysiwyg ul.panel li.outdent { background-position: -80px 0; }

div.wysiwyg ul.panel li.subscript { background-position: -64px -16px; }
div.wysiwyg ul.panel li.superscript { background-position: -80px -16px; }

div.wysiwyg ul.panel li.undo { background-position: 0 -64px; }
div.wysiwyg ul.panel li.redo { background-position: -16px -64px; }

div.wysiwyg ul.panel li.insertOrderedList { background-position: -32px -48px; }
div.wysiwyg ul.panel li.insertUnorderedList { background-position: -16px -48px; }
div.wysiwyg ul.panel li.insertHorizontalRule { background-position: 0 -48px; }

div.wysiwyg ul.panel li.h1 { background-position: 0 -32px; }
div.wysiwyg ul.panel li.h2 { background-position: -16px -32px; }
div.wysiwyg ul.panel li.h3 { background-position: -32px -32px; }
div.wysiwyg ul.panel li.h4 { background-position: -48px -32px; }
div.wysiwyg ul.panel li.h5 { background-position: -64px -32px; }
div.wysiwyg ul.panel li.h6 { background-position: -80px -32px; }

div.wysiwyg ul.panel li.cut { background-position: -32px -64px; }
div.wysiwyg ul.panel li.copy { background-position: -48px -64px; }
div.wysiwyg ul.panel li.paste { background-position: -64px -64px; }
div.wysiwyg ul.panel li.insertTable { background-position: -64px -48px; }

div.wysiwyg ul.panel li.increaseFontSize { background-position: -16px -80px; }
div.wysiwyg ul.panel li.decreaseFontSize { background-position: -32px -80px; }

div.wysiwyg ul.panel li.createLink { background-position: -80px -48px; }
div.wysiwyg ul.panel li.insertImage { background-position: -80px -80px; }

div.wysiwyg ul.panel li.html { background-position: -47px -46px; }
div.wysiwyg ul.panel li.removeFormat { background-position: -80px -63px; }

div.wysiwyg ul.panel li.empty { background-position: -64px -80px; }

div.wysiwyg iframe { border: 0;  clear: left; margin: 4px 0 0 1px; }

