<div class="pagination">
    {% if entries.has_next or entries.has_previous %}
        {% trans "Pages:" %}
    {% endif %}   

    {% if entries.has_previous %}
        <a href="?page={{ entries.previous_page_number }}" title="{% trans "&lt; goto previous page" %}" class="previous">&#x22D8; {% trans "previous" %}</a>
    {% endif %}
    
    <span class="pagelist">
    {% for entry in entries.paginator.page_range %}
        {% if entry == entries.number %}
            <strong>{{ entry }}</strong>
        {% else %}
            <a href="?page={{ entry }}">{{ entry }}</a>
        {% endif %}
    {% endfor %}
    </span>
 
    {% if entries.has_next %}
        <a href="?page={{ entries.next_page_number }}" title="{% trans "goto next page &gt;" %}" class="next">{% trans "next" %} &#x22D9;</a>
    {% endif %}
</div>