<fieldset class="tag_cloud"><legend>{% trans 'tag cloud' %}</legend>
{% for tag in tag_cloud %}
    {% if not forloop.first %}|{% endif %}
    
    {% if tag.name in used_tags %}
        <strong style="font-size:{{ tag.font_size }}em;">{{ tag.name }}</strong>
    {% else %}
        <a href="{% url Blog-tag_view tags=tag.name %}" style="font-size:{{ tag.font_size }}em;" rel="nofollow">{{ tag.name }}</a>
    {% endif %}
    
    {% if add_tag_filter_link %}
        {% include "blog/includes/add_tag_filter.html" %}
    {% endif %}
{% endfor %}
</fieldset>