{% extends template_name %}
{% load comments %}

{% block content %}
<div class="{{ CSS_PLUGIN_CLASS_NAME }} blog">
{% include "blog/includes/pagination.html" %}
{% include "blog/includes/tagcloud.html" %}

{% if not entries %}no blog entry exists{% endif %}
{% for entry in entries.object_list %}
<fieldset class="entry">
   {% include "blog/includes/blog_entry.html" %}
   {% get_comment_count for entry as comment_count %}            
   <a href="{{ entry.get_absolute_url }}" class="comment_link" title="Display all comments | Leave a comment">{{ comment_count }} comment{{ comment_count|pluralize:"s" }}...</a>
</fieldset>
{% endfor %}
</div>

<fieldset class="feed_selection"><legend>{% trans "Syndication feed format:" %}</legend>
<ul>
{% for filename in filenames %}
    <li>
        {% if tags %}
            <a href="{% url Blog-tag_feed tags filename %}">{% url Blog-tag_feed tags filename %}</a>
        {% else %}      
            <a href="{% url Blog-feed filename %}">{% url Blog-feed filename %}</a>
        {% endif %}
        <small>(
        {% if filename == "feed.rss" %}
            <a href="{% trans "http://en.wikipedia.org/wiki/RSS" %}">Really Simple Syndication</a> v2.01rev2
        {% endif %}
        {% if filename == "feed.atom" %}   
            <a href="{% trans "http://en.wikipedia.org/wiki/Atom_(standard)" %}">Atom Syndication Format</a> v1.0
        {% endif %}
        )
        </small>
    </li>    
{% endfor %}
</lu>
</fieldset>
{% include "blog/includes/pagination.html" %}
{% endblock content %}