{% extends "pylucid_admin/base_site.html" %}
{% load i18n %}

{% block content %}
<!-- view_content block -->
<p>Simple form from model generator.
Based on <a href="http://code.djangoproject.com/attachment/wiki/FormGenScript/form_generator.py">form_generator.py</a>,
see also <a href="http://code.djangoproject.com/wiki/FormGenScript">code.djangoproject.com/wiki/FormGenScript</a>.</p>
<ul>
	{% for no,model in models_dict.items %}
	<li><a href="{% url Internal-form_generator model_no=no %}">{{ model }}</a></li>
	{% endfor %}
</ul>
{% if output %}{{ output }}
{% else %}
    <p>Please select.</p>
{% endif %}
<!-- view_content block end -->
{% endblock %}