{% if debug %}<!-- pylucid plugin ./admin_menu/includes/superfish_extrahead.html START -->{% endif %}
{% compress css %}
<link rel="stylesheet" type="text/css" media="screen" href="{{ STATIC_URL }}PyLucid/superfish/superfish.css" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" />
<link rel="stylesheet" type="text/css" media="screen" href="{{ STATIC_URL }}PyLucid/superfish/pylucid_superfish.css" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" />

{# this must be here in the template and can't stored into the css file, because of the url #}
<style type="text/css">
<!--
/* setup superfish background urls */
.sf-sub-indicator {
    background: url('{{ STATIC_URL }}PyLucid/superfish/arrows-ffffff.png') no-repeat -10px -100px; /* 8-bit indexed alpha png. IE6 gets solid image only */
}
.sf-shadow ul {
    background: url('{{ STATIC_URL }}PyLucid/superfish/shadow.png') no-repeat bottom right;
}
-->
</style>
{% endcompress %}

{% compress js %}
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/superfish/superfish.js" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" ></script>
<script type="text/javascript" src="{{ STATIC_URL }}PyLucid/superfish/pylucid_superfish.js" onerror="JavaScript:alert('Error loading file ['+this.href+'] !');" ></script>
{% endcompress %}

{% if debug %}<!-- pylucid plugin ./admin_menu/includes/superfish_extrahead.html END -->{% endif %}