<style type="{{ instance.mimetype }}" {{ instance.html_attributes }} charset="utf-8">
/* ********* START headfile stylesheet '{{ instance.filepath }}' ********* */
{{ rendered_content }}
/* ********* END headfile stylesheet '{{ instance.filepath }}' ********* */
</style>