{% extends template_name %}

{% block content %}
<div class="{{ CSS_PLUGIN_CLASS_NAME }} blog">
{% include "blog/includes/tagcloud.html" %}

<fieldset class="entry">
    {% include "blog/includes/blog_entry.html" %}
</fieldset>

<fieldset class="archive_links"><legend>{% trans 'archive' %}</legend>
{% spaceless %}
/<a href="{% url Blog-year_archive entry.url_date|date:"Y" %}"
    title="{% blocktrans with entry.url_date|date:"Y" as year %}{{ year }} year archive{% endblocktrans %}">
    {{ entry.url_date|date:"Y" }}
</a>
/<a href="{% url Blog-month_archive entry.url_date|date:"Y" entry.url_date|date:"m" %}"
    title="{% blocktrans with entry.url_date|date:"YEAR_MONTH_FORMAT" as month %}{{ month }} month archive{% endblocktrans %}">
    {{ entry.url_date|date:"m" }}
</a>
/<a href="{% url Blog-day_archive entry.url_date|date:"Y" entry.url_date|date:"m" entry.url_date|date:"d" %}"
    title="{% blocktrans with entry.url_date|date:"MONTH_DAY_FORMAT" as day %}{{ day }} day archive{% endblocktrans %}">
    {{ entry.url_date|date:"d" }}
</a>
/
{% endspaceless %}
</fieldset>
</div>
{% endblock content %}