{% extends "pylucid/css_anchor_div.html" %}
{% load tagging_tags %}

{% block plugin_content %}
{% tags_for_object pagemeta as tags %}
{% if tags %}
<fieldset class="taglist"><legend>tag navi</legend>
{% for tag in tags %}
    {% if not forloop.first %}|{% endif %}
    <a href="?tag_navi={{ tag.name }}" rel="nofollow">{{ tag.name }}</a>
{% endfor %}
</fieldset>
{% endif %}
{% endblock plugin_content %}