{% for node in nodes %}
    {% if node.pagemeta %}
    <li>
        {% if node.current %}<strong>{% endif %}
        <a href="{{ node.pagemeta.get_absolute_url }}" hreflang="{{ node.pagemeta.language.code }}" title="{{ node.pagemeta.get_title }}" class="level_{{ node.level }}{% if node.active %} active{% endif %}{% if node.current %} current{% endif %}">{{ node.pagemeta.get_name }}</a>
        {% if node.current %}</strong>{% endif %}

        {% if node.subnodes %}
    	    {% with "sf_main_menu/sf_main_menu_items.html" as filename %}
    	    {% with node.subnodes as nodes %}
    	       <ul>{% include filename %}</ul>
    	    {% endwith %}
    	    {% endwith %}
         {% endif %}    
    </li>
    {% endif %}
{% endfor %}