{% extends "page_admin/markup_help_base.html" %}

{% block content %}{{ block.super }}
TODO
<h2>links</h2>
<ul>
	<li><a class="add_openinwindow" href="http://docutils.sourceforge.net/rst.html">docutils.sourceforge.net/rst.html</a></li>
	<li><a class="add_openinwindow" href="http://docutils.sourceforge.net/docs/user/rst/quickref.html">quick reference</a></li>
</ul>
{% include "page_admin/includes/markup_help_common.html" %}
{% endblock content %}