<a href="{{ item.get_absolute_url }}" title="{% blocktrans %}Open this content in {{ language }}.{% endblocktrans %}">
  {% blocktrans %}This content exist also in {{ language }}.{% endblocktrans %}
</a>

