{% if colorscheme %}
    <a href="{% url admin:pylucid_colorscheme_change colorscheme.pk %}" class="add_openinwindow" title="{% trans "edit colorscheme" %}">
    {% if add_colorscheme_name %}
        {{ colorscheme.name }}:
    {% endif %}
{% endif %}
{% for color in colors %}<span style="background-color:#{{ color.value }};">&nbsp;&nbsp;&nbsp;</span>{% endfor %}
{% if colorscheme %}
    </a>
{% endif %}
