<script type="{{ instance.mimetype }}" {{ instance.html_attributes }} charset="utf-8">
// ********* START headfile javascript '{{ instance.filepath }}' *********
{{ rendered_content }}
// ********* END headfile javascript '{{ instance.filepath }}' *********
</script>