{% extends "admin/change_form.html" %}
{% load i18n %}


{% block content %}
<!-- admin/pylucid/editablehtmlheadfile/change_form - content - START -->
<ul>
    <li>
        Please don't rename colornames in CSS files here!
        (Rename them by editing the <a href="{% url admin:pylucid_colorscheme_changelist %}" class="add_openinwindow">colorscheme</a>.)
    </li>
    <li>{% include "admin/pylucid/includes/design_link.html" %}</li>
</ul>
<!-- admin/pylucid/editablehtmlheadfile/change_form - content - END -->
{{ block.super }}{% endblock %}
