# coding: utf-8

"""
    i18n models
    ~~~~~~~~~~~
    
    TODO: move language models from pylucid app to this app!
    
    :copyleft: 2011 by the PyLucid team, see AUTHORS for more details.
    :license: GNU GPL v3 or above, see LICENSE for more details
"""
