<object width="{{ width }}" height="{{ height }}">
    <param name="movie" value="http://www.youtube.com/v/{{ id }}?fs=1&amp;hd=1&amp;rel=0&amp;hl={{ page_language }}"></param>
    <param name="allowFullScreen" value="true"></param>
    <embed src="http://www.youtube.com/v/{{ id }}?fs=1&amp;hd=1&amp;rel=0&amp;hl={{ page_language }}" type="application/x-shockwave-flash" allowfullscreen="true" width="{{ width }}" height="{{ height }}"></embed>
</object>